A simple library for building Twilio-powered Django webapps.


## Meta

* author: Randall Degges
* email:  rdegges@gmail.com
* status: maintained, stable


## Purpose

Building telephony applications with Twilio is easy, but not simple.

django-twilio is my attempt at reducing some of the complexities of telephony
development with Twilio--namely, implementing common patterns, helpers, etc., so
that you can truly focus on the core application logic and leave out all the
rest.


## Documentation

The documentation is hosted at ReadTheDocs. You can check out the docs
[here](http://django-twilio.rtfd.org/ "django-twilio latest").
